@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import json
-import warnings
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -72,7 +71,6 @@ class BaseView:
     def __init__(
         self,
         schema: BaseSchema,
-        graphiql: str | None = None,
         graphql_ide: GraphQL_IDE | None = "graphiql",
         allow_queries_via_get: bool = True,
         multipart_uploads_enabled: bool = False,
@@ -81,16 +79,7 @@ class BaseView:
         self.schema = schema
         self.allow_queries_via_get = allow_queries_via_get
         self.multipart_uploads_enabled = multipart_uploads_enabled
-
-        if graphiql is not None:
-            warnings.warn(
-                "The `graphiql` argument is deprecated in favor of `graphql_ide`",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            self.graphql_ide = "graphiql" if graphiql else None
-        else:
-            self.graphql_ide = graphql_ide
+        self.graphql_ide = graphql_ide
 
         super().__init__(**kwargs)
 
@@ -144,7 +133,6 @@ class GraphQLView(
     ],
     View,
 ):
-    graphiql: bool | None = None
     graphql_ide: GraphQL_IDE | None = "graphiql"
     allow_queries_via_get = True
     schema: BaseSchema = None  # type: ignore
@@ -193,7 +181,6 @@ class AsyncGraphQLView(
     ],
     View,
 ):
-    graphiql: bool | None = None
     graphql_ide: GraphQL_IDE | None = "graphiql"
     allow_queries_via_get = True
     schema: BaseSchema = None  # type: ignore
